==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Wtyczka %1 nie jest kompatybilna z systemem.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Ustawienia Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Wyłączyć</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Włączyć</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Ustawienia Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>Podłączono %1</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Łączenie...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Wyłączony</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Dodaj układ klawiatury</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Data i czas</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Czas 12 godziny</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>czas 24 godziny</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Ustawienia czasu</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Włącz sieć</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Wyłącz sieć</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ustawienia sieci</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Czy na pewno chcesz opróżnić %1 przedmiotów?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>To działanie nie może być cofnięte</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Nieznane urządzenie</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Nieznany wolumin</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Dysk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Odmontuj wszystkie</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Launcher</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Tryb modny</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Tryb wydajny</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Góra</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dół</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Do lewej</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Do prawej</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Zawsze wyświetlaj</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Zawsze ukrywaj</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Mądre ukrywanie</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tryb</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Położenie</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stan</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Wtyczki</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Widok wielozadaniowości</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Odepnij</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Wyłącz połączenie przewodowe</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Włącz połączenie przewodowe</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Wyłącz połączenie bezprzewodowe</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Włącz połączenie bezprzewodowe</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Wyłącz sieć</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Włącz sieć</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ustawienia sieci</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Urządzenie jest wyłączone</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Połączenie bezprzewodowe: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Połączenie przewodowe: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Brak połączenia</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Łączenie</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Połączono, ale brak dostępu do Internetu</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kabel sieciowy jest odłączony</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Sieć bezprzewodowa</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Sieć przewodowa</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Połączenie nieudane</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Sieć przewodowa</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Sieć przewodowa %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Zasilanie</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Ustawienia zasilania</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Poziom: %1, pozostało: %2min</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Poziom: %1, pozostało: %2:%3</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Ładowanie %1, %2min do końca</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Ładowanie %1, %2:%3 do końca</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Naładowana</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Pojemność %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Ładowanie %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Pojemność %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Pojemność %1, w pełni naładowana</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Wyświetl pulpit</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Odepnij</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Zasilanie</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernacja</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zablokuj</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Przełącz konto</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Ustawienia zasilania</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Urządzenie</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Wyłącz wyciszenie</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Wycisz</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Ustawienia dźwięku</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Głośność %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Dźwięk</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Kosz</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Kosz - %1 plik</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Kosz - %1 pliki</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Opróżnij</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Obszar powiadamiania</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Sieć bezprzewodowa</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Sieć bezprzewodowa %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.38.1.orig.tar.xz: dde-dock-5.5.38.1/translations/dde-dock_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Wtyczka %1 nie jest kompatybilna z systemem.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Tryb samolotowy</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Tryb samolotowy jest aktywny</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Wyłączyć</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Włączyć</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Ustawienia trybu samolotowego</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Tryb samolotowy jest wyłączony</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Tryb samolotowy</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Ustawienia Bluetooth</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Włącz</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Ustawienia Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>Podłączono %1</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Łączenie...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Wyłączony</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Dodaj układ klawiatury</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Data i czas</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Format 12-godzinny</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Format 24-godzinny</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Ustawienia czasu</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Czy na pewno chcesz trwale usunąć %1 przedmiotów?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Tej akcji nie można cofnąć</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Nieznane urządzenie</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Nieznany wolumin</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Dysk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Odmontuj wszystkie</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Launcher</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Wyjdź z trybu bezpiecznego</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Dok - Tryb bezpieczny</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Dok jest w trybie bezpiecznym, wyjdź z niego aby wyświetlić go poprawnie</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Tryb modny</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Tryb wydajny</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Góra</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dół</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Do lewej</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Do prawej</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Zawsze wyświetlaj</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Zawsze ukrywaj</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Inteligentne ukrywanie</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tryb</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Położenie</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stan</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Ustawienia doka</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Wiele ekranów</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Strefa wtyczek</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Wybierz, które wtyczki pojawią się w doku</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Tryb modny</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Tryb wydajny</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tryb</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Góra</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Dół</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Lewo</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Prawo</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Położenie</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Zawsze wyświetlaj</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Zawsze ukrywaj</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Inteligentne ukrywanie</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Mały</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Ogromny</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Pokaż dok</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Na ekranie, tam gdzie jest kursor</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Tylko na ekranie głównym</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Widok wielozadaniowości</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Odepnij</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Klawiatura ekranowa</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Zasilanie</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Ustawienia zasilania</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Poziom: %1, pozostało: %2min</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Poziom: %1, pozostało: %2:%3</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Ładowanie %1, %2min do końca</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Ładowanie %1, %2:%3 do końca</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Pojemność %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Ładowanie %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Pojemność %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Pojemność %1, w pełni naładowana</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Dok</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Wyświetl pulpit</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Odepnij</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Zasilanie</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernacja</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zablokuj</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Przełącz konto</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Ustawienia zasilania</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Urządzenie</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Wyłącz wyciszenie</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Wycisz</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Ustawienia dźwięku</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Głośność %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Dźwięk</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Kosz</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Kosz - %1 plik</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Kosz - %1 pliki</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Przenieś do kosza</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Opróżnij</translation>
    </message>
</context>
</TS>
